CampaignFlow.Client.AgencySuggestions (CampaignFlow Client v2.0.0)
View SourceAgency suggestion operations for the Campaign Flow API.
Provides search suggestions for real estate agencies based on partial strings.
Summary
Functions
Suggests real estate agencies matching the given partial string.
Functions
@spec list( CampaignFlow.Client.t(), keyword() ) :: CampaignFlow.Client.Request.response()
Suggests real estate agencies matching the given partial string.
Options
:q- Query string for searching agencies:limit- Maximum number of suggestions to return
Examples
{:ok, suggestions} = CampaignFlow.Client.AgencySuggestions.list(client, q: "ABC Real")